PROFILE_URL = 'https://cloudac.mildom.com/nonolive/gappserv/user/profileV2'
PLAYBACK_LIST_URL = 'https://cloudac.mildom.com/nonolive/videocontent/profile/playbackList'

CHAT_URL = 'https://cloudac.mildom.com/nonolive/videocontent/chat/replay'
PLAYBACK_URL = 'https://cloudac.mildom.com/nonolive/videocontent/playback/getPlaybackDetail'
LIVE_URL = 'wss://jp-room1.mildom.com'
LIVE_META_URL = 'https://cloudac.mildom.com/nonolive/gappserv/live/enterstudio'

